@@ -32,8 +32,10 @@ renv_lockfile_init_r_repos <- function(project) {
   repos[repos == "@CRAN@"] <- "https://cloud.r-project.org"
 
   # remove RSPM bits from URL
-  pattern <- "/__linux__/[^/]+/"
-  repos <- sub(pattern, "/", repos)
+  if (config$rspm.enabled()) {
+    pattern <- "/__[^_]+__/[^/]+/"
+    repos <- sub(pattern, "/", repos)
+  }
 
   # force as list
   repos <- as.list(repos)
